@@ -408,6 +408,24 @@ assay_facets: Facets = {
             "Plots showing Copy Number Alteration (CNA) across the whole genome for each sample for the top 2 solutions generated by ichorCNA.",
         ),
     },
+    "Microbiome": {
+        "Source": FacetConfig(
+            [
+                "/microbiome/forward.fastq.gz",
+                "/microbiome/forward_index.fastq.gz",
+                "/microbiome/reverse.fastq.gz",
+                "/microbiome/reverse_index.fastq.gz",
+            ]
+        ),
+        "OTU Tables": FacetConfig(
+            ["/microbiome/otu_table.tsv"],
+            "Operational taxonomic unit matrix.",
+        ),
+        "Batch-level Summary Plots": FacetConfig(
+            ["/microbiome_analysis/summary.pdf"],
+            "Plots showing analysis summary for microbiome.",
+        ),
+    },
 }
 
 clinical_facets: Facets = {
@@ -447,6 +465,10 @@ analysis_ready_facets = {
         ["/ctdna_analysis/summary_plots.pdf"],
         "Plots showing Copy Number Alteration (CNA) across the whole genome for each sample for the top 2 solutions generated by ichorCNA.",
     ),
+    "Microbiome": FacetConfig(
+        ["/microbiome_analysis/summary.pdf"],
+        "Plots showing analysis summary for microbiome.",
+    ),
 }
 
 facets_dict: Dict[str, Facets] = {
