@@ -135,9 +135,9 @@ class CommonColumns(BaseModel):  # type: ignore
 
     __abstract__ = True  # Indicate that this isn't a Table schema
 
-    _created = Column(DateTime, default=func.now())
-    _updated = Column(DateTime, default=func.now())
-    _etag = Column(String(40))
+    _created = Column(DateTime, default=func.now(), nullable=False)
+    _updated = Column(DateTime, default=func.now(), nullable=False)
+    _etag = Column(String(40), nullable=False)
     id = Column(Integer, primary_key=True, autoincrement=True, nullable=False)
 
     def compute_etag(self) -> str:
